@@ -377,7 +377,7 @@ method column_names(@rest) {
         # rename column names
         my @values = $self->_columns->values;
         $self->_columns->clear;
-        $self->_columns->push( List::AllUtils::zip( @colnames, @values ) );
+        $self->_columns->push( List::MoreUtils::zip( @colnames, @values ) );
 	}
 	return [ $self->_columns->keys ];
 }
@@ -1092,7 +1092,7 @@ Data::Frame - data frame implementation
 
 =head1 VERSION
 
-version 0.0055
+version 0.0056
 
 =head1 STATUS
 
